Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Salto_id.PathSourceFormatter of Salto paths
Constructor of path recovered from the typed OCaml AST
from_ident id fields desc returns the path obtained by projecting fields on the identifier id
split p returns a list of flat paths (head, names) where head is the head identifier of the sub-path and names is the list of projection names of the sub-path. NB: the returned list should contain at least one element, and if the path is non-applicative, the returned list is a singleton